<?php
// $Id: template.php,v 1.1 2009/02/22 10:12:04 kong Exp $

function phptemplate_preprocess_comment_wrapper(&$vars) {
  // get total number of comments
  $comments_count = comment_num_all($vars['node']->nid);

  if ($comments_count == 0) {
    $vars['comments_count'] = 'No comments yet';
  }
  else {
    $vars['comments_count'] = $comments_count . format_plural($comments_count, ' comment', ' comments');
  }
}

function phptemplate_preprocess_comment(&$vars) {
  // format $submitted
  $vars['submitted'] = l($vars['date'],
    'node/' . $vars['node']->nid,
    array('fragment' => 'comment-' . $vars['comment']->cid)
  );

  // change (not verified) to (visitor)
  $vars['author'] = str_replace('(not verified)', '(visitor)', $vars['author']);
  
  // add a special class for node author
  if ($vars['comment']->uid == $vars['node']->uid) {
    $vars['author_comment'] = true;
  }
}

function phptemplate_preprocess_page(&$vars) {
  $url = url('rss.xml', array('absolute' => TRUE));

  // use feedburner url if the module exists
  if (module_exists('feedburner')) {
    $feedburner = db_result(db_query("SELECT feedburner FROM {feedburner} WHERE path = '%s'", 'rss.xml'));
    $url = _feedburner_construct_url($feedburner);
  }

  // add "Subscribe to feed" menu to $primary_links
  $vars['primary_links']['menu-rss'] = array(
    /* 'href' => url('rss.xml', array('absolute' => TRUE)), */
    'href' => $url,
    'title' => 'Subscribe to feed',
  );
}

function phptemplate_preprocess_node(&$vars) {
  // Add node regions content
  $vars['node_top'] = theme('blocks', 'node_top');
  $vars['node_bottom'] = theme('blocks', 'node_bottom');
  
  // format $submitted
  if (isset($vars['submitted']) && $vars['submitted'] != '') {
    $author = theme('username', $vars['node']);
    $vars['submitted'] = 'Posted on ' . format_date($vars['created'], 'medium') . ', by ' . $author;
  }

  // add "Read the rest of this entry" link
  // to the end of teaser like in WordPress
  if (isset($vars['node']->links['node_read_more'])) {
    $read_more_link = l('Read the rest of this entry' . ' »',
      'node/'. $vars['node']->nid,
      array(
        'attributes' => array(
          'title' => 'Read the rest of "' . $vars['node']->title . '"',
        ),
        'query' => NULL,
        'fragment' => NULL,
        'absolute' => FALSE,
        'html' => TRUE,
      )
    );

    $content = $vars['node']->content;
    $content['read-more'] = array(
      '#weight' => 20,
      '#value' => '<p class="read-more">' . $read_more_link . '</p>',
      '#title' => '',
      '#description' => '',
      '#printed' => 1,
    );

    _plainscape_sort_content($content);
    $vars['content'] = _plainscape_render_content($content);

    // remove the original "read more" link from $links
    unset($vars['node']->links['node_read_more']);
    $vars['links'] = theme('links', $vars['node']->links, array('class' => 'links inline'));
  }

  // format taxonomy list, code adapted from "Acquia Marina" theme
  if (module_exists('taxonomy')) {
    $vocabularies = taxonomy_get_vocabularies($vars['node']->type);
    $output = '';
    $vocab_delimiter = '';
    foreach ($vocabularies as $vocabulary) {
      $terms = taxonomy_node_get_terms_by_vocabulary($vars['node'], $vocabulary->vid);
      if ($terms) {
        $output .= '<li class="vocab vocab-'. $vocabulary->vid .'"><span class="vocab-name">'. $vocabulary->name .':</span> <span class="vocab-list">';
        $links = array();
        foreach ($terms as $term) {        
          $links[] = l($term->name, taxonomy_term_path($term), array('attributes' => array('rel' => 'tag', 'title' => strip_tags($term->description))));
        }

        //$output .= $vocab_delimiter;    // Add comma between vocabularies
        //$vocab_delimiter = ', ';        // Use a comma delimiter after first displayed vocabulary

        $output .= implode(", ", $links);
        $output .= '</span></li>';
      }
    }
    if ($output != '') {
      $output = '<ul class="taxonomy">'. $output .'</ul>';
    }
    $vars['terms'] = $output;
  }
  else {
    $vars['terms'] = '';
  }

  // format node links
  if (isset($vars['node']->links['comment_add'])) {
    if ($vars['teaser']) {
      $vars['node']->links['comment_add']['title'] = 'No comments' . ' »';
    }
  }

  if (isset($vars['node']->links['comment_new_comments'])) {
    $new_comments_title = $vars['node']->links['comment_new_comments']['title'];
    $vars['node']->links['comment_new_comments']['title'] = '(' . $new_comments_title . ')';
  }

  if (isset($vars['node']->links['comment_comments'])) {
    $vars['node']->links['comment_comments']['title'] .= ' »';
  }

  $vars['links'] = theme('links', $vars['node']->links, array('class' => 'links inline'));
  
  // add previous/next links
  $prev_next_links = _plainscape_prev_next_links($vars['node']);
  
  if (!$teaser && !empty($prev_next_links)) {
    $vars['prev_next_links'] = $prev_next_links;
  }
}

function _plainscape_sort_content(&$content) {
  // sort items in $content according to #weight
  foreach($content as $c) {
     $sort_helper[] = $c['#weight'];
  }

  array_multisort($sort_helper, SORT_ASC, $content);
}

function _plainscape_render_content($content) {
  // concat everything in $content except #children
  foreach($content as $key => $field) {
    if ($key != '#children') {
      $output .= $field['#value'];
    }
  }

  return $output;
}

/**
 * Returns a formatted list of 5 recent comments to be displayed in the comment block.
 *
 * Override the default number of 10 recent comments
 * and display only 5 recent comments.
 */
function phptemplate_comment_block() {
  $items = array();
  foreach (comment_get_recent(5) as $comment) {
    $items[] = l($comment->subject, 'node/'. $comment->nid, array('fragment' => 'comment-'. $comment->cid)) .'<br />'. t('@time ago', array('@time' => format_interval(time() - $comment->timestamp)));
  }
  if ($items) {
    return theme('item_list', $items);
  }
}

/**
 * Displays previous/next links on each node
 */
function _plainscape_prev_next_links($node) {
  $output = '';
  $max_length = 28;

  $sql = "SELECT nid, title FROM {node} WHERE type = '%s' AND status = %d AND created < %d ORDER BY created DESC";
  $result = db_query_range(db_rewrite_sql($sql), $node->type, 1, $node->created, 0, 1);
  $prev = db_fetch_object($result);
  
  $title_trimmed = $prev->title;
  
  if (mb_strlen($prev->title) > $max_length) {
    $title_trimmed = mb_substr($prev->title, 0, $max_length - 4) . '...';
  }
  
  if ($prev) {
    $output .= '<div class="previous-link">';
    $output .= l('<strong>&laquo; Previous | </strong>' . $title_trimmed,
      'node/' . $prev->nid,
      array(
        'attributes' => array('title' => 'Read "' . $prev->title . '"'),
        'html' => true
      )
    );
    $output .= '</div>';
  }
  
  $sql = "SELECT nid, title FROM {node} WHERE type = '%s' AND status = %d AND created > %d ORDER BY created ASC";
  $result = db_query_range(db_rewrite_sql($sql), $node->type, 1, $node->created, 0, 1);
  $next = db_fetch_object($result);
  
  $title_trimmed = $next->title;
  
  if (mb_strlen($next->title) > $max_length) {
    $title_trimmed = mb_substr($next->title, 0, $max_length - 4) . '...';
  }
  
  if ($next) {
    $output .= '<div class="next-link">';
    $output .= l($title_trimmed . '<strong> | Next &raquo;</strong>',
      'node/' . $next->nid,
      array(
        'attributes' => array('title' => 'Read "' . $next->title .'"'),
        'html' => true
      )
    );
    $output .= '</div>';
  }
  
  return $output;
}